@@ -1,10 +1,13 @@
 #' Derive Death Cause
 #'
+#' @description
+#' `r lifecycle::badge("superseded")` The `derive_var_dthcaus()`
+#' function has been superseded in favor of `derive_vars_extreme_event()`.
+#'
 #' Derive death cause (`DTHCAUS`) and add traceability variables if required.
 #'
-#' @param dataset Input dataset.
-#'
-#'   The variables specified by `subject_keys` are required.
+#' @param dataset
+#'   `r roxygen_param_dataset(expected_vars = c("subject_keys"))`
 #'
 #' @param source_datasets A named `list` containing datasets in which to search for the
 #'   death cause
@@ -23,8 +26,8 @@
 #' equivalent, the first source will be kept, so the user should provide the inputs in
 #' the preferred order.
 #'
-#' @family der_adsl
-#' @keywords der_adsl
+#' @family superseded
+#' @keywords superseded
 #'
 #' @return The input dataset with `DTHCAUS` variable added.
 #'
@@ -238,6 +241,11 @@ derive_var_dthcaus <- function(dataset,
 
 #' Create a `dthcaus_source` Object
 #'
+#' @description
+#' `r lifecycle::badge("superseded")` The `derive_var_dthcaus()`
+#' function and `dthcaus_source()` have been superseded in favor of
+#' `derive_vars_extreme_event()`.
+#'
 #' @param dataset_name The name of the dataset, i.e. a string, used to search for
 #'   the death cause.
 #'
@@ -280,8 +288,8 @@ derive_var_dthcaus <- function(dataset,
 #'
 #' @param set_values_to Variables to be set to trace the source dataset
 #'
-#' @keywords source_specifications
-#' @family source_specifications
+#' @family superseded
+#' @keywords superseded
 #'
 #'
 #' @export
@@ -317,7 +325,7 @@ dthcaus_source <- function(dataset_name,
                            set_values_to = NULL,
                            traceability_vars = NULL) {
   if (!is.null(traceability_vars)) {
-    deprecate_warn(
+    deprecate_stop(
       "0.12.0",
       "dthcaus_source(traceability_vars = )",
       "dthcaus_source(set_values_to = )"
