@@ -16,7 +16,9 @@
 #' response value can be confirmed by a subsequent assessment. This is commonly
 #' used in endpoints such as best overall response.
 #'
-#' @param dataset Input dataset
+#' @param dataset `r roxygen_param_dataset(expected_vars = c("by_vars", "order"))`
+#'
+#' @param dataset_add Additional dataset
 #'
 #'   The variables specified for `by_vars`, `join_vars`, and `order` are
 #'   expected.
@@ -26,51 +28,90 @@
 #'   The specified variables are used as by variables for joining the input
 #'   dataset with itself.
 #'
+#'  `r roxygen_param_by_vars()`
+#'
 #' @param join_vars Variables to keep from joined dataset
 #'
 #'   The variables needed from the other observations should be specified for
 #'   this parameter. The specified variables are added to the joined dataset
 #'   with suffix ".join". For example to select all observations with `AVALC ==
 #'   "Y"` and `AVALC == "Y"` for at least one subsequent visit `join_vars =
-#'   exprs(AVALC, AVISITN)` and `filter = AVALC == "Y" & AVALC.join == "Y" &
-#'   AVISITN < AVISITN.join` could be specified.
+#'   exprs(AVALC, AVISITN)` and `filter_join = AVALC == "Y" & AVALC.join == "Y"
+#'   & AVISITN < AVISITN.join` could be specified.
 #'
 #'   The `*.join` variables are not included in the output dataset.
 #'
-#' @param join_type Observations to keep after joining
-#'
-#'   The argument determines which of the joined observations are kept with
-#'   respect to the original observation. For example, if `join_type =
-#'   "after"` is specified all observations after the original observations are
-#'   kept.
-#'
-#'   *Permitted Values:* `"before"`, `"after"`, `"all"`
-#'
 #' @param first_cond Condition for selecting range of data
 #'
+#'   `r lifecycle::badge("deprecated")`
+#'
+#'   This argument is *deprecated*, please use `first_cond_upper` instead.
+#'
 #'   If this argument is specified, the other observations are restricted up to
 #'   the first observation where the specified condition is fulfilled. If the
 #'   condition is not fulfilled for any of the subsequent observations, all
 #'   observations are removed.
 #'
+#' @param first_cond_lower Condition for selecting range of data (before)
+#'
+#'   If this argument is specified, the other observations are restricted from
+#'   the first observation before the current observation where the specified
+#'   condition is fulfilled up to the current observation. If the condition is
+#'   not fulfilled for any of the other observations, no observations are
+#'   considered, i.e., the observation is not flagged.
+#'
+#'   This parameter should be specified if `filter_join` contains summary
+#'   functions which should not apply to all observations but only from a
+#'   certain observation before the current observation up to the current
+#'   observation. For an example see the last example below.
+#'
+#' @param first_cond_upper Condition for selecting range of data (after)
+#'
+#'   If this argument is specified, the other observations are restricted up to
+#'   the first observation where the specified condition is fulfilled. If the
+#'   condition is not fulfilled for any of the other observations, no
+#'   observations are considered, i.e., the observation is not flagged.
+#'
+#'   This parameter should be specified if `filter_join` contains summary
+#'   functions which should not apply to all observations but only up to the
+#'   confirmation assessment. For an example see the last example below.
+#'
 #' @param order Order
 #'
 #'   The observations are ordered by the specified order.
 #'
+#'   `r roxygen_order_na_handling()`
+#'
 #'   *Permitted Values:* list of expressions created by `exprs()`, e.g.,
 #'   `exprs(ADT, desc(AVAL))`
 #'
 #' @param tmp_obs_nr_var Temporary observation number
 #'
-#'   The specified variable is added to the input dataset and set to the
-#'   observation number with respect to `order`. For each by group (`by_vars`)
-#'   the observation number starts with `1`. The variable can be used in the
-#'   conditions (`filter`, `first_cond`). It is not included in the output
-#'   dataset. It can be used to select consecutive observations or the last
-#'   observation (see last example below).
+#'   The specified variable is added to the input dataset (`dataset`) and the
+#'   additional dataset (`dataset_add`). It is set to the observation number
+#'   with respect to `order`. For each by group (`by_vars`) the observation
+#'   number starts with `1`. The variable can be used in the conditions
+#'   (`filter_join`, `first_cond_upper`, `first_cond_lower`). It is not included
+#'   in the output dataset. It can also be used to select consecutive
+#'   observations or the last observation (see example below).
+#'
+#' @param filter_add Filter for additional dataset (`dataset_add`)
+#'
+#'   Only observations from `dataset_add` fulfilling the specified condition are
+#'   joined to the input dataset. If the argument is not specified, all
+#'   observations are joined.
+#'
+#'   Variables created by the `order` argument can be used in the condition.
+#'
+#'   The condition can include summary functions. The additional dataset is
+#'   grouped by the by variables (`by_vars`).
 #'
 #' @param filter Condition for selecting observations
 #'
+#'   `r lifecycle::badge("deprecated")`
+#'
+#'   This argument is *deprecated*, please use `filter_join` instead.
+#'
 #'   The filter is applied to the joined dataset for selecting the confirmed
 #'   observations. The condition can include summary functions. The joined
 #'   dataset is grouped by the original observations. I.e., the summary function
@@ -82,28 +123,52 @@
 #'   confirmation observation the response is "CR" or "NE" and there is at most
 #'   one "NE".
 #'
+#' @param filter_join Condition for selecting observations
+#'
+#'   The filter is applied to the joined dataset for selecting the confirmed
+#'   observations. The condition can include summary functions like `all()` or
+#'   `any()`. The joined dataset is grouped by the original observations. I.e.,
+#'   the summary function are applied to all observations up to the confirmation
+#'   observation. For example in the oncology setting when using this function
+#'   for confirmed best overall response,  `filter_join = AVALC == "CR" &
+#'   all(AVALC.join %in% c("CR", "NE")) & count_vals(var = AVALC.join, val =
+#'   "NE") <= 1` selects observations with response "CR" and for all
+#'   observations up to the confirmation observation the response is "CR" or
+#'   "NE" and there is at most one "NE".
+#'
 #' @param check_type Check uniqueness?
 #'
 #'   If `"warning"` or `"error"` is specified, the specified message is issued
 #'   if the observations of the input dataset are not unique with respect to the
 #'   by variables and the order.
 #'
-#'   *Default:* `"none"`
-#'
 #'   *Permitted Values:* `"none"`, `"warning"`, `"error"`
 #'
+#' @inheritParams get_joined_data
+#'
 #' @details
 #'
 #'   The following steps are performed to produce the output dataset.
 #'
 #'   ## Step 1
 #'
-#'   The input dataset is joined with itself by the variables specified for
-#'   `by_vars`. From the right hand side of the join only the variables
-#'   specified for `join_vars` are kept. The suffix ".join" is added to these
-#'   variables.
+#'   - The variables specified by `order` are added to the additional dataset
+#'   (`dataset_add`).
 #'
-#'   For example, for `by_vars = USUBJID`, `join_vars = exprs(AVISITN, AVALC)` and input dataset
+#'   - The variables specified by `join_vars` are added to the additional dataset
+#'   (`dataset_add`).
+#'
+#'   - The records from the additional dataset (`dataset_add`) are restricted to
+#'   those matching the `filter_add` condition.
+#'
+#'   Then the  input dataset (`dataset`) is joined with the restricted
+#'   additional dataset by the variables specified for `by_vars`. From the
+#'   additional dataset only the variables specified for `join_vars` are kept.
+#'   The suffix ".join" is added to those variables which are also present in
+#'   the input dataset.
+#'
+#'   For example, for `by_vars = USUBJID`, `join_vars = exprs(AVISITN, AVALC)`
+#'   and input dataset and additional dataset
 #'
 #'   ```{r eval=FALSE}
 #'   # A tibble: 2 x 4
@@ -142,17 +207,26 @@
 #'
 #'   ## Step 3
 #'
-#'   If `first_cond` is specified, for each observation of the input dataset the
-#'   joined dataset is restricted to observations up to the first observation
-#'   where `first_cond` is fulfilled (the observation fulfilling the condition
-#'   is included). If for an observation of the input dataset the condition is
-#'   not fulfilled, the observation is removed.
+#'   If `first_cond_lower` is specified, for each observation of the input
+#'   dataset the joined dataset is restricted to observations from the first
+#'   observation where `first_cond_lower` is fulfilled (the observation
+#'   fulfilling the condition is included) up to the observation of the input
+#'   dataset. If for an observation of the input dataset the condition is not
+#'   fulfilled, the observation is removed.
+#'
+#'   If `first_cond_upper` is specified, for each observation of the input
+#'   dataset the joined dataset is restricted to observations up to the first
+#'   observation where `first_cond_upper` is fulfilled (the observation
+#'   fulfilling the condition is included). If for an observation of the input
+#'   dataset the condition is not fulfilled, the observation is removed.
+#'
+#'   For an example see the last example in the "Examples" section.
 #'
 #'   ## Step 4
 #'
 #'   The joined dataset is grouped by the observations from the input dataset
 #'   and restricted to the observations fulfilling the condition specified by
-#'   `filter`.
+#'   `filter_join`.
 #'
 #'   ## Step 5
 #'
@@ -193,11 +267,12 @@
 #'
 #' filter_joined(
 #'   adae,
+#'   dataset_add = adae,
 #'   by_vars = exprs(USUBJID),
 #'   join_vars = exprs(ACOVFL, ADY),
 #'   join_type = "all",
 #'   order = exprs(ADY),
-#'   filter = ADURN > 30 & ACOVFL.join == "Y" & ADY >= ADY.join - 7
+#'   filter_join = ADURN > 30 & ACOVFL.join == "Y" & ADY >= ADY.join - 7
 #' )
 #'
 #' # filter observations with AVALC == "Y" and AVALC == "Y" at a subsequent visit
@@ -216,11 +291,12 @@
 #'
 #' filter_joined(
 #'   data,
+#'   dataset_add = data,
 #'   by_vars = exprs(USUBJID),
 #'   join_vars = exprs(AVALC, AVISITN),
 #'   join_type = "after",
 #'   order = exprs(AVISITN),
-#'   filter = AVALC == "Y" & AVALC.join == "Y" & AVISITN < AVISITN.join
+#'   filter_join = AVALC == "Y" & AVALC.join == "Y" & AVISITN < AVISITN.join
 #' )
 #'
 #' # select observations with AVALC == "CR", AVALC == "CR" at a subsequent visit,
@@ -245,12 +321,13 @@
 #'
 #' filter_joined(
 #'   data,
+#'   dataset_add = data,
 #'   by_vars = exprs(USUBJID),
 #'   join_vars = exprs(AVALC),
 #'   join_type = "after",
 #'   order = exprs(AVISITN),
-#'   first_cond = AVALC.join == "CR",
-#'   filter = AVALC == "CR" & all(AVALC.join %in% c("CR", "NE")) &
+#'   first_cond_upper = AVALC.join == "CR",
+#'   filter_join = AVALC == "CR" & all(AVALC.join %in% c("CR", "NE")) &
 #'     count_vals(var = AVALC.join, val = "NE") <= 1
 #' )
 #'
@@ -277,12 +354,13 @@
 #'
 #' filter_joined(
 #'   data,
+#'   dataset_add = data,
 #'   by_vars = exprs(USUBJID),
 #'   join_vars = exprs(AVALC, ADY),
 #'   join_type = "after",
 #'   order = exprs(ADY),
-#'   first_cond = AVALC.join %in% c("CR", "PR") & ADY.join - ADY >= 20,
-#'   filter = AVALC == "PR" &
+#'   first_cond_upper = AVALC.join %in% c("CR", "PR") & ADY.join - ADY >= 20,
+#'   filter_join = AVALC == "PR" &
 #'     all(AVALC.join %in% c("CR", "PR", "NE")) &
 #'     count_vals(var = AVALC.join, val = "NE") <= 1 &
 #'     (
@@ -309,23 +387,71 @@
 #'
 #' filter_joined(
 #'   data,
+#'   dataset_add = data,
 #'   by_vars = exprs(USUBJID),
 #'   tmp_obs_nr_var = tmp_obs_nr,
 #'   join_vars = exprs(CRIT1FL),
 #'   join_type = "all",
 #'   order = exprs(AVISITN),
-#'   filter = CRIT1FL == "Y" & CRIT1FL.join == "Y" &
+#'   filter_join = CRIT1FL == "Y" & CRIT1FL.join == "Y" &
 #'     (tmp_obs_nr + 1 == tmp_obs_nr.join | tmp_obs_nr == max(tmp_obs_nr.join))
 #' )
 #'
+#' # first_cond_lower and first_cond_upper argument
+#' myd <- tribble(
+#'   ~subj, ~day, ~val,
+#'   "1",      1, "++",
+#'   "1",      2, "-",
+#'   "1",      3, "0",
+#'   "1",      4, "+",
+#'   "1",      5, "++",
+#'   "1",      6, "-",
+#'   "2",      1, "-",
+#'   "2",      2, "++",
+#'   "2",      3, "+",
+#'   "2",      4, "0",
+#'   "2",      5, "-",
+#'   "2",      6, "++"
+#' )
+#'
+#' # select "0" where all results from the first "++" before the "0" up to the "0"
+#' # (excluding the "0") are "+" or "++"
+#' filter_joined(
+#'   myd,
+#'   dataset_add = myd,
+#'   by_vars = exprs(subj),
+#'   order = exprs(day),
+#'   join_vars = exprs(val),
+#'   join_type = "before",
+#'   first_cond_lower = val.join == "++",
+#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
+#' )
+#'
+#' # select "0" where all results from the "0" (excluding the "0") up to the first
+#' # "++" after the "0" are "+" or "++"
+#' filter_joined(
+#'   myd,
+#'   dataset_add = myd,
+#'   by_vars = exprs(subj),
+#'   order = exprs(day),
+#'   join_vars = exprs(val),
+#'   join_type = "after",
+#'   first_cond_upper = val.join == "++",
+#'   filter_join = val == "0" & all(val.join %in% c("+", "++"))
+#' )
 filter_joined <- function(dataset,
+                          dataset_add,
                           by_vars,
                           join_vars,
                           join_type,
                           first_cond = NULL,
+                          first_cond_lower = NULL,
+                          first_cond_upper = NULL,
                           order,
                           tmp_obs_nr_var = NULL,
-                          filter,
+                          filter_add = NULL,
+                          filter_join,
+                          filter = NULL,
                           check_type = "warning") {
   # Check input parameters
   assert_vars(by_vars)
@@ -336,10 +462,24 @@ filter_joined <- function(dataset,
       values = c("before", "after", "all"),
       case_sensitive = FALSE
     )
-  first_cond <- assert_filter_cond(enexpr(first_cond), optional = TRUE)
+  first_cond_lower <- assert_filter_cond(enexpr(first_cond_lower), optional = TRUE)
+  first_cond_upper <- assert_filter_cond(enexpr(first_cond_upper), optional = TRUE)
+  if (!missing(first_cond)) {
+    deprecate_warn(
+      "1.0.0",
+      "filter_joined(first_cond=)",
+      "filter_joined(first_cond_upper=)"
+    )
+    first_cond_upper <- assert_filter_cond(enexpr(first_cond), optional = TRUE)
+  }
   assert_expr_list(order)
   tmp_obs_nr_var <- assert_symbol(enexpr(tmp_obs_nr_var), optional = TRUE)
-  filter <- assert_filter_cond(enexpr(filter))
+  filter_add <- assert_filter_cond(enexpr(filter_add), optional = TRUE)
+  filter_join <- assert_filter_cond(enexpr(filter_join))
+  if (!missing(filter)) {
+    deprecate_warn("1.0.0", "filter_joined(filter=)", "filter_joined(filter_join=)")
+    filter_join <- assert_filter_cond(enexpr(filter))
+  }
   check_type <-
     assert_character_scalar(
       check_type,
@@ -348,63 +488,34 @@ filter_joined <- function(dataset,
     )
   assert_data_frame(
     dataset,
+    required_vars = expr_c(by_vars, extract_vars(order))
+  )
+
+  assert_data_frame(
+    dataset_add,
     required_vars = expr_c(by_vars, join_vars, extract_vars(order))
   )
 
-  # number observations of the input dataset to get a unique key
-  # (by_vars and tmp_obs_nr_var)
   if (is.null(tmp_obs_nr_var)) {
     tmp_obs_nr_var <- get_new_tmp_var(dataset, prefix = "tmp_obs_nr_")
   }
-  data <- dataset %>%
-    derive_var_obs_number(
-      new_var = !!tmp_obs_nr_var,
-      by_vars = by_vars,
-      order = order,
-      check_type = check_type
-    )
-  # join the input dataset with itself such that to each observation of the
-  # input dataset all following observations are joined
-  data_joined <-
-    left_join(
-      data,
-      select(data, !!!by_vars, !!!join_vars, !!tmp_obs_nr_var),
-      by = vars2chr(by_vars),
-      suffix = c("", ".join")
-    )
-  if (join_type != "all") {
-    operator <- c(before = "<", after = ">")
-
-    data_joined <- filter(
-      data_joined,
-      !!parse_expr(paste0(
-        as_name(tmp_obs_nr_var), ".join",
-        operator[join_type],
-        as_name(tmp_obs_nr_var)
-      ))
-    )
-  }
-
-  if (!is.null(first_cond)) {
-    # select all observations up to the first confirmation observation
-    data_joined <- filter_relative(
-      data_joined,
-      by_vars = expr_c(by_vars, tmp_obs_nr_var),
-      condition = !!first_cond,
-      order = exprs(!!parse_expr(paste0(as_name(tmp_obs_nr_var), ".join"))),
-      mode = "first",
-      selection = "before",
-      inclusive = TRUE,
-      keep_no_ref_groups = FALSE
-    )
-  }
-
-  # apply confirmation condition, which may include summary functions
-  data_joined %>%
-    group_by(!!!by_vars, !!tmp_obs_nr_var) %>%
-    filter(!!filter) %>%
+  get_joined_data(
+    dataset,
+    dataset_add = dataset_add,
+    by_vars = by_vars,
+    join_vars = join_vars,
+    join_type = join_type,
+    first_cond_lower = !!first_cond_lower,
+    first_cond_upper = !!first_cond_upper,
+    order = order,
+    tmp_obs_nr_var = !!tmp_obs_nr_var,
+    filter_add = !!filter_add,
+    filter_join = !!filter_join,
+    check_type = check_type
+  ) %>%
     # select one observation of each group, as the joined variables are removed
     # it doesn't matter which one, so we take just the first one
+    group_by(!!!by_vars, !!tmp_obs_nr_var) %>%
     slice(1L) %>%
     ungroup() %>%
     select(colnames(dataset))
