@@ -160,21 +160,6 @@ qs_gdssf <- tibble::tribble(
   "P0002",     28L,               "GDS02-Feel Full of Energy", "GDS0213",          "VISIT 2",         2, "2012-12-15",    "YES",        0L,
   "P0002",     29L,                     "GDS02-Feel Hopeless", "GDS0214",          "VISIT 2",         2, "2012-12-15",     "NO",        0L,
   "P0002",     30L,   "GDS02-Most People Better Off Than You", "GDS0215",          "VISIT 2",         2, "2012-12-15",     "NO",        0L,
-  "P0002",     31L,               "GDS02-Satisfied With Life", "GDS0201",          "VISIT 3",         3, "2013-01-12",    "YES",        0L,
-  "P0002",     32L,  "GDS02-Dropped Activities and Interests", "GDS0202",          "VISIT 3",         3, "2013-01-12",    "YES",        1L,
-  "P0002",     33L,                     "GDS02-Life Is Empty", "GDS0203",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     34L,                       "GDS02-Bored Often", "GDS0204",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     35L,         "GDS02-Good Spirits Most of Time", "GDS0205",          "VISIT 3",         3, "2013-01-12",    "YES",        0L,
-  "P0002",     36L, "GDS02-Afraid of Something Bad Happening", "GDS0206",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     37L,           "GDS02-Feel Happy Most of Time", "GDS0207",          "VISIT 3",         3, "2013-01-12",     "NO",        1L,
-  "P0002",     38L,               "GDS02-Often Feel Helpless", "GDS0208",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     39L,               "GDS02-Prefer to Stay Home", "GDS0209",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     40L,                   "GDS02-Memory Problems", "GDS0210",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     41L,             "GDS02-Wonderful to Be Alive", "GDS0211",          "VISIT 3",         3, "2013-01-12",     "NO",        1L,
-  "P0002",     42L,                    "GDS02-Feel Worthless", "GDS0212",          "VISIT 3",         3, "2013-01-12",    "YES",        1L,
-  "P0002",     43L,               "GDS02-Feel Full of Energy", "GDS0213",          "VISIT 3",         3, "2013-01-12",    "YES",        0L,
-  "P0002",     44L,                     "GDS02-Feel Hopeless", "GDS0214",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
-  "P0002",     45L,   "GDS02-Most People Better Off Than You", "GDS0215",          "VISIT 3",         3, "2013-01-12",     "NO",        0L,
   "P0002",     46L,               "GDS02-Satisfied With Life", "GDS0201",          "VISIT 4",         4, "2013-02-13",     "NO",        1L,
   "P0002",     47L,  "GDS02-Dropped Activities and Interests", "GDS0202",          "VISIT 4",         4, "2013-02-13",    "YES",        1L,
   "P0002",     48L,                     "GDS02-Life Is Empty", "GDS0203",          "VISIT 4",         4, "2013-02-13",     "NO",        0L,
