@@ -199,7 +199,7 @@ adeg <- adeg %>%
   derive_summary_records(
     dataset_add = adeg,
     by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars, PARAMCD, AVISITN, AVISIT, ADT),
-    filter = dplyr::n() >= 2 & PARAMCD != "EGINTP",
+    filter_add = dplyr::n() >= 2 & PARAMCD != "EGINTP",
     set_values_to = exprs(
       AVAL = mean(AVAL, na.rm = TRUE),
       DTYPE = "AVERAGE"
